@@ -165,7 +165,6 @@ class File(object):
         info_id = res['fileInfoId']
         http_response = {}
         headers = {}
-
         try:
             if url.find('.blob.core.windows.net') is not -1:
                 headers['x-ms-meta-file_info_id'] = info_id
@@ -178,6 +177,12 @@ class File(object):
                 http_response = self._put(url=url, data=data, headers=headers)
             http_response.raise_for_status()
         except Exception as err:
+            print({
+                'url': url,
+                'info_id': info_id,
+                'headers': headers,
+                'http_response': http_response,
+            })
             content = http_response.content
             print(f'Error occurred when put object: {err}, {content}, {traceback.format_exc()}')
             return False
