@@ -26,7 +26,7 @@ class Query(object):
         self.sql = sql
         self.data_format = data_format
         self.offset = 0
-        self.limit = 500
+        self.limit = 5000000
         self._columns = None
         self.create_sql_query_payload = gen_create_sql_query_payload(
             workspace_id=workspace_id,
@@ -110,13 +110,22 @@ class Query(object):
         query_id = self.id
         workspace_id = self.workspace_id
         urls = self.request.get(f'api/v1/query/{query_id}/result/signedUrls?workspaceId={workspace_id}').get('signedUrls')
+        # get columns and row_count by api
+        self.__get_sql_result_by_restful(0, 0)
         if len(urls) is 0:
             df = pd.DataFrame({})
         else:
-            dfs = [self.__get_pd_by_parquet_file(url) for url in urls]
-            df = pd.concat(dfs)
-        self._columns = list(map(lambda column: {'name': column}, list(df.columns)))
-        self.row_count = df.shape[0]
+            dfs = []
+            count = 0
+            for url in urls:
+                df = self.__get_pd_by_parquet_file(url)
+                count += df.shape[0]
+                dfs.append(df)
+                # if we get enough data, stop getting the next one
+                if count >= limit + offset:
+                    df = pd.concat(dfs)
+                    break
+            self._columns = list(map(lambda column: {'name': column}, list(df.columns)))
         self.data = df.iloc[offset:limit + offset, :].to_numpy().tolist()
 
     def __get_sql_result_by_restful(self, limit, offset):
